Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1687)

Unified Diff: compiler/javatests/com/google/dart/compiler/resolver/ResolverTestCase.java

Issue 9633009: Use Element instead of Symbol. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 8 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: compiler/javatests/com/google/dart/compiler/resolver/ResolverTestCase.java
diff --git a/compiler/javatests/com/google/dart/compiler/resolver/ResolverTestCase.java b/compiler/javatests/com/google/dart/compiler/resolver/ResolverTestCase.java
index a001ba19b4d08a8178448cf0efaffc593fcc5376..98fcb20f1ea6dbcae429acfcacd979009789c90d 100644
--- a/compiler/javatests/com/google/dart/compiler/resolver/ResolverTestCase.java
+++ b/compiler/javatests/com/google/dart/compiler/resolver/ResolverTestCase.java
@@ -134,7 +134,7 @@ abstract class ResolverTestCase extends TestCase {
}
/**
* Look for DartIdentifier nodes in the tree whose symbols are null. They should all either
* be resolved, or marked as an unresolved element.
*/
static class ResolverAuditVisitor extends ASTVisitor<Void> {
@@ -143,8 +143,8 @@ abstract class ResolverTestCase extends TestCase {
@Override
public Void visitIdentifier(DartIdentifier node) {
- if (node.getSymbol() == null) {
- failures.add("Identifier: " + node.getTargetName() + " has null symbol @ ("
+ if (node.getElement() == null) {
+ failures.add("Identifier: " + node.getName() + " has null element @ ("
+ node.getSourceLine() + ":" + node.getSourceColumn() + ")");
}
return null;
@@ -159,7 +159,7 @@ abstract class ResolverTestCase extends TestCase {
root.accept(visitor);
List<String> results = visitor.getFailures();
if (results.size() > 0) {
- StringBuilder out = new StringBuilder("Missing symbols found in AST\n");
+ StringBuilder out = new StringBuilder("Missing elements found in AST\n");
Joiner.on("\n").appendTo(out, results);
fail(out.toString());
}
@@ -134,7 +134,7 @@ abstract class ResolverTestCase extends TestCase {
}
/**
- * Look for DartIdentifier nodes in the tree whose symbols are null. They should all either
+ * Look for DartIdentifier nodes in the tree whose elements are null. They should all either
* be resolved, or marked as an unresolved element.
*/

Powered by Google App Engine
This is Rietveld 408576698